import importlib_metadata
from flask_resources.serializers.json import JSONSerializer
from invenio_drafts_resources.resources import RecordResourceConfig
from invenio_records_resources.resources.records.headers import etag_headers
from oarepo_runtime.i18n import lazy_gettext as _
from oarepo_runtime.resources.responses import ExportableResponseHandler

from nr_metadata.documents.resources.records.ui import DocumentsUIJSONSerializer


class DocumentsResourceConfig(RecordResourceConfig):
    """DocumentsRecord resource config."""

    blueprint_name = "documents"
    url_prefix = "/nr-metadata-documents/"

    @property
    def response_handlers(self):
        entrypoint_response_handlers = {}
        for x in importlib_metadata.entry_points(
            group="invenio.nr_metadata.documents.response_handlers"
        ):
            entrypoint_response_handlers.update(x.load())
        return {
            "application/json": ExportableResponseHandler(
                export_code="json",
                name=_("Native JSON"),
                serializer=JSONSerializer(),
                headers=etag_headers,
            ),
            "application/vnd.inveniordm.v1+json": ExportableResponseHandler(
                export_code="ui_json",
                name=_("Native UI JSON"),
                serializer=DocumentsUIJSONSerializer(),
            ),
            **entrypoint_response_handlers,
        }

    @property
    def error_handlers(self):
        entrypoint_error_handlers = {}
        for x in importlib_metadata.entry_points(
            group="invenio.nr_metadata.documents_record.error_handlers"
        ):
            entrypoint_error_handlers.update(x.load())
        return {**super().error_handlers, **entrypoint_error_handlers}

    @property
    def request_body_parsers(self):
        entrypoint_request_bodyparsers = {}
        for x in importlib_metadata.entry_points(
            group="invenio.nr_metadata.documents_record.request_bodyparsers"
        ):
            entrypoint_request_bodyparsers.update(x.load())
        return {
            **super().request_body_parsers,
            **entrypoint_request_bodyparsers,
        }



from invenio_drafts_resources.resources import RecordResource


class DocumentsResource(RecordResource):
    """DocumentsRecord resource."""

    # here you can for example redefine
    # create_url_rules function to add your own rules



from oarepo_runtime.services.results import RecordItem, RecordList


class DataciteRecordItem(RecordItem):
    """DataciteRecord record item."""

    components = [*RecordItem.components]


class DataciteRecordList(RecordList):
    """DataciteRecord record list."""

    components = [*RecordList.components]



from oarepo_runtime.records.dumpers import SearchDumper
from oarepo_runtime.records.systemfields.mapping import SystemFieldDumperExt

from nr_metadata.data.records.dumpers.edtf import DataEDTFIntervalDumperExt
from nr_metadata.data.records.dumpers.multilingual import MultilingualSearchDumperExt


class DataDumper(SearchDumper):
    """DataRecord opensearch dumper."""

    extensions = [
        SystemFieldDumperExt(),
        DataEDTFIntervalDumperExt(),
        MultilingualSearchDumperExt(),
    ]



import marshmallow as ma


class FillMissingVersionMixin(ma.Schema):
    @ma.post_dump
    def fill_missing_version(self, value, **kwargs):
        value.setdefault("metadata", {}).setdefault(
            "version", value.get("versions", {}).get("index")
        )
        return value



from oarepo_runtime.services.results import RecordItem, RecordList


class CommonRecordItem(RecordItem):
    """CommonRecord record item."""

    components = [*RecordItem.components]


class CommonRecordList(RecordList):
    """CommonRecord record list."""

    components = [*RecordList.components]



from flask import g
from flask_resources import BaseListSchema
from flask_resources.serializers import JSONSerializer
from oarepo_runtime.resources import LocalizedUIJSONSerializer

from nr_metadata.common.services.records.ui_schema_common import NRCommonRecordUISchema


class CommonUIJSONSerializer(LocalizedUIJSONSerializer):
    """UI JSON serializer."""

    def __init__(self):
        """Initialise Serializer."""
        super().__init__(
            format_serializer_cls=JSONSerializer,
            object_schema_cls=NRCommonRecordUISchema,
            list_schema_cls=BaseListSchema,
            schema_context={"object_key": "ui", "identity": g.identity},
        )



import re
from typing import List, Dict

from invenio_search.engine import dsl
from invenio_records_resources.services.records.facets.facets import (
    TermsFacet,
    LabelledFacetMixin,
)

from oarepo_runtime.i18n import get_locale


class KeywordsFacet(TermsFacet):

    def get_localized_keyword_field(self):
        locale = get_locale()
        return f"{self._params['field']}.{locale}"

    def get_aggregation(self):
        """
        Return the aggregation object.
        """
        locale = get_locale()
        agg = dsl.A(
            self.agg_type,
            **{**self._params, "field": self.get_localized_keyword_field()},
        )
        if self._metric:
            agg.metric("metric", self._metric)
        return agg

    def add_filter(self, filter_values):
        locale = get_locale()
        if filter_values:
            return dsl.query.Terms(
                _expand__to_dot=False,
                **{self.get_localized_keyword_field(): filter_values},
            )



import re
from functools import cached_property

from invenio_rdm_records.services.pids import PIDManager, PIDsService

from nr_metadata.common import config


class CommonExt:

    def __init__(self, app=None):

        if app:
            self.init_app(app)

    def init_app(self, app):
        """Flask application initialization."""
        self.app = app

        self.init_config(app)
        if not self.is_inherited():
            self.register_flask_extension(app)

        for method in dir(self):
            if method.startswith("init_app_callback_"):
                getattr(self, method)(app)

    def register_flask_extension(self, app):

        app.extensions["nr_metadata.common"] = self

    def init_config(self, app):
        """Initialize configuration."""
        for identifier in dir(config):
            if re.match("^[A-Z_0-9]*$", identifier) and not identifier.startswith("_"):
                if isinstance(app.config.get(identifier), list):
                    app.config[identifier] += getattr(config, identifier)
                elif isinstance(app.config.get(identifier), dict):
                    for k, v in getattr(config, identifier).items():
                        if k not in app.config[identifier]:
                            app.config[identifier][k] = v
                else:
                    app.config.setdefault(identifier, getattr(config, identifier))

    def is_inherited(self):
        from importlib_metadata import entry_points

        ext_class = type(self)
        for ep in entry_points(group="invenio_base.apps"):
            loaded = ep.load()
            if loaded is not ext_class and issubclass(ext_class, loaded):
                return True
        for ep in entry_points(group="invenio_base.api_apps"):
            loaded = ep.load()
            if loaded is not ext_class and issubclass(ext_class, loaded):
                return True
        return False

    @cached_property
    def service_records(self):
        service_config = config.COMMON_RECORD_SERVICE_CONFIG
        if hasattr(service_config, "build"):
            config_class = service_config.build(self.app)
        else:
            config_class = service_config()

        service_kwargs = {
            "pids_service": PIDsService(config_class, PIDManager),
            "config": config_class,
        }
        return config.COMMON_RECORD_SERVICE_CLASS(
            **service_kwargs,
            files_service=self.service_files,
            draft_files_service=self.service_draft_files
        )

    @cached_property
    def resource_records(self):
        return config.COMMON_RECORD_RESOURCE_CLASS(
            service=self.service_records,
            config=config.COMMON_RECORD_RESOURCE_CONFIG(),
        )

    def init_app_callback_rdm_models(self, app):

        app.config.setdefault("GLOBAL_SEARCH_MODELS", [])
        for cfg in app.config["GLOBAL_SEARCH_MODELS"]:
            if cfg["model_service"] == RDM_MODEL_CONFIG["model_service"]:
                break
        else:
            app.config["GLOBAL_SEARCH_MODELS"].append(RDM_MODEL_CONFIG)

        app.config.setdefault("RDM_MODELS", [])
        for cfg in app.config["RDM_MODELS"]:
            if cfg["model_service"] == RDM_MODEL_CONFIG["model_service"]:
                break
        else:
            app.config["RDM_MODELS"].append(RDM_MODEL_CONFIG)


RDM_MODEL_CONFIG = {  # allows merging stuff from other builders
    "service_id": "common",
    # deprecated
    "model_service": "nr_metadata.common.services.records.service.CommonService",
    # deprecated
    "service_config": "nr_metadata.common.services.records.config.CommonServiceConfig",
    "api_service": "nr_metadata.common.services.records.service.CommonService",
    "api_service_config": (
        "nr_metadata.common.services.records.config.CommonServiceConfig"
    ),
    "api_resource": "nr_metadata.common.resources.records.resource.CommonResource",
    "api_resource_config": (
        "nr_metadata.common.resources.records.config.CommonResourceConfig"
    ),
    "ui_resource_config": "ui.nr_metadata.common.CommonUIResourceConfig",
    "record_cls": "nr_metadata.common.records.api.CommonRecord",
    "pid_type": "common",
}



from oarepo_runtime.services.results import RecordItem, RecordList


class DocumentsRecordItem(RecordItem):
    """DocumentsRecord record item."""

    components = [*RecordItem.components]


class DocumentsRecordList(RecordList):
    """DocumentsRecord record list."""

    components = [*RecordList.components]



"""Facet definitions."""

from invenio_records_resources.services.records.facets import TermsFacet
from oarepo_runtime.i18n import lazy_gettext as _
from oarepo_runtime.services.facets.date import DateTimeFacet

access_embargo_active = TermsFacet(
    field="access.embargo.active", label=_("access/embargo/active.label")
)

access_embargo_until = DateTimeFacet(
    field="access.embargo.until", label=_("access/embargo/until.label")
)

access_files = TermsFacet(field="access.files", label=_("access/files.label"))

access_record = TermsFacet(field="access.record", label=_("access/record.label"))

access_status = TermsFacet(field="access.status", label=_("access/status.label"))

metadata_alternateIdentifiers_alternateIdentifier = TermsFacet(
    field="metadata.alternateIdentifiers.alternateIdentifier",
    label=_("metadata/alternateIdentifiers/alternateIdentifier.label"),
)

metadata_alternateIdentifiers_alternateIdentifierType = TermsFacet(
    field="metadata.alternateIdentifiers.alternateIdentifierType",
    label=_("metadata/alternateIdentifiers/alternateIdentifierType.label"),
)

metadata_container_firstPage = TermsFacet(
    field="metadata.container.firstPage", label=_("metadata/container/firstPage.label")
)

metadata_container_title = TermsFacet(
    field="metadata.container.title", label=_("metadata/container/title.label")
)

metadata_container_type = TermsFacet(
    field="metadata.container.type", label=_("metadata/container/type.label")
)

metadata_contributors_affiliation_affiliationIdentifier = TermsFacet(
    field="metadata.contributors.affiliation.affiliationIdentifier",
    label=_("metadata/contributors/affiliation/affiliationIdentifier.label"),
)

metadata_contributors_affiliation_affiliationIdentifierScheme = TermsFacet(
    field="metadata.contributors.affiliation.affiliationIdentifierScheme",
    label=_("metadata/contributors/affiliation/affiliationIdentifierScheme.label"),
)

metadata_contributors_affiliation_name = TermsFacet(
    field="metadata.contributors.affiliation.name",
    label=_("metadata/contributors/affiliation/name.label"),
)

metadata_contributors_affiliation_schemeURI = TermsFacet(
    field="metadata.contributors.affiliation.schemeURI",
    label=_("metadata/contributors/affiliation/schemeURI.label"),
)

metadata_contributors_contributorType = TermsFacet(
    field="metadata.contributors.contributorType",
    label=_("metadata/contributors/contributorType.label"),
)

metadata_contributors_familyName = TermsFacet(
    field="metadata.contributors.familyName",
    label=_("metadata/contributors/familyName.label"),
)

metadata_contributors_givenName = TermsFacet(
    field="metadata.contributors.givenName",
    label=_("metadata/contributors/givenName.label"),
)

metadata_contributors_lang = TermsFacet(
    field="metadata.contributors.lang", label=_("metadata/contributors/lang.label")
)

metadata_contributors_name = TermsFacet(
    field="metadata.contributors.name", label=_("metadata/contributors/name.label")
)

metadata_contributors_nameIdentifiers_nameIdentifier = TermsFacet(
    field="metadata.contributors.nameIdentifiers.nameIdentifier",
    label=_("metadata/contributors/nameIdentifiers/nameIdentifier.label"),
)

metadata_contributors_nameIdentifiers_nameIdentifierScheme = TermsFacet(
    field="metadata.contributors.nameIdentifiers.nameIdentifierScheme",
    label=_("metadata/contributors/nameIdentifiers/nameIdentifierScheme.label"),
)

metadata_contributors_nameIdentifiers_schemeURI = TermsFacet(
    field="metadata.contributors.nameIdentifiers.schemeURI",
    label=_("metadata/contributors/nameIdentifiers/schemeURI.label"),
)

metadata_contributors_nameType = TermsFacet(
    field="metadata.contributors.nameType",
    label=_("metadata/contributors/nameType.label"),
)

metadata_creators_affiliation_affiliationIdentifier = TermsFacet(
    field="metadata.creators.affiliation.affiliationIdentifier",
    label=_("metadata/creators/affiliation/affiliationIdentifier.label"),
)

metadata_creators_affiliation_affiliationIdentifierScheme = TermsFacet(
    field="metadata.creators.affiliation.affiliationIdentifierScheme",
    label=_("metadata/creators/affiliation/affiliationIdentifierScheme.label"),
)

metadata_creators_affiliation_name = TermsFacet(
    field="metadata.creators.affiliation.name",
    label=_("metadata/creators/affiliation/name.label"),
)

metadata_creators_affiliation_schemeURI = TermsFacet(
    field="metadata.creators.affiliation.schemeURI",
    label=_("metadata/creators/affiliation/schemeURI.label"),
)

metadata_creators_familyName = TermsFacet(
    field="metadata.creators.familyName", label=_("metadata/creators/familyName.label")
)

metadata_creators_givenName = TermsFacet(
    field="metadata.creators.givenName", label=_("metadata/creators/givenName.label")
)

metadata_creators_lang = TermsFacet(
    field="metadata.creators.lang", label=_("metadata/creators/lang.label")
)

metadata_creators_name = TermsFacet(
    field="metadata.creators.name", label=_("metadata/creators/name.label")
)

metadata_creators_nameIdentifiers_nameIdentifier = TermsFacet(
    field="metadata.creators.nameIdentifiers.nameIdentifier",
    label=_("metadata/creators/nameIdentifiers/nameIdentifier.label"),
)

metadata_creators_nameIdentifiers_nameIdentifierScheme = TermsFacet(
    field="metadata.creators.nameIdentifiers.nameIdentifierScheme",
    label=_("metadata/creators/nameIdentifiers/nameIdentifierScheme.label"),
)

metadata_creators_nameIdentifiers_schemeURI = TermsFacet(
    field="metadata.creators.nameIdentifiers.schemeURI",
    label=_("metadata/creators/nameIdentifiers/schemeURI.label"),
)

metadata_creators_nameType = TermsFacet(
    field="metadata.creators.nameType", label=_("metadata/creators/nameType.label")
)

metadata_dates_date = DateTimeFacet(
    field="metadata.dates.date", label=_("metadata/dates/date.label")
)

metadata_dates_dateInformation = TermsFacet(
    field="metadata.dates.dateInformation",
    label=_("metadata/dates/dateInformation.label"),
)

metadata_dates_dateType = TermsFacet(
    field="metadata.dates.dateType", label=_("metadata/dates/dateType.label")
)

metadata_descriptions_descriptionType = TermsFacet(
    field="metadata.descriptions.descriptionType",
    label=_("metadata/descriptions/descriptionType.label"),
)

metadata_descriptions_lang = TermsFacet(
    field="metadata.descriptions.lang", label=_("metadata/descriptions/lang.label")
)

metadata_doi = TermsFacet(field="metadata.doi", label=_("metadata/doi.label"))

metadata_formats = TermsFacet(
    field="metadata.formats", label=_("metadata/formats.label")
)

metadata_fundingReferences_awardNumber = TermsFacet(
    field="metadata.fundingReferences.awardNumber",
    label=_("metadata/fundingReferences/awardNumber.label"),
)

metadata_fundingReferences_awardTitle = TermsFacet(
    field="metadata.fundingReferences.awardTitle",
    label=_("metadata/fundingReferences/awardTitle.label"),
)

metadata_fundingReferences_awardURI = TermsFacet(
    field="metadata.fundingReferences.awardURI",
    label=_("metadata/fundingReferences/awardURI.label"),
)

metadata_fundingReferences_funderIdentifier = TermsFacet(
    field="metadata.fundingReferences.funderIdentifier",
    label=_("metadata/fundingReferences/funderIdentifier.label"),
)

metadata_fundingReferences_funderIdentifierType = TermsFacet(
    field="metadata.fundingReferences.funderIdentifierType",
    label=_("metadata/fundingReferences/funderIdentifierType.label"),
)

metadata_fundingReferences_funderName = TermsFacet(
    field="metadata.fundingReferences.funderName",
    label=_("metadata/fundingReferences/funderName.label"),
)

metadata_geoLocations_geoLocationBox_eastBoundLongitude = TermsFacet(
    field="metadata.geoLocations.geoLocationBox.eastBoundLongitude",
    label=_("metadata/geoLocations/geoLocationBox/eastBoundLongitude.label"),
)

metadata_geoLocations_geoLocationBox_northBoundLatitude = TermsFacet(
    field="metadata.geoLocations.geoLocationBox.northBoundLatitude",
    label=_("metadata/geoLocations/geoLocationBox/northBoundLatitude.label"),
)

metadata_geoLocations_geoLocationBox_southBoundLatitude = TermsFacet(
    field="metadata.geoLocations.geoLocationBox.southBoundLatitude",
    label=_("metadata/geoLocations/geoLocationBox/southBoundLatitude.label"),
)

metadata_geoLocations_geoLocationBox_westBoundLongitude = TermsFacet(
    field="metadata.geoLocations.geoLocationBox.westBoundLongitude",
    label=_("metadata/geoLocations/geoLocationBox/westBoundLongitude.label"),
)

metadata_geoLocations_geoLocationPlace = TermsFacet(
    field="metadata.geoLocations.geoLocationPlace",
    label=_("metadata/geoLocations/geoLocationPlace.label"),
)

metadata_geoLocations_geoLocationPoint_pointLatitude = TermsFacet(
    field="metadata.geoLocations.geoLocationPoint.pointLatitude",
    label=_("metadata/geoLocations/geoLocationPoint/pointLatitude.label"),
)

metadata_geoLocations_geoLocationPoint_pointLongitude = TermsFacet(
    field="metadata.geoLocations.geoLocationPoint.pointLongitude",
    label=_("metadata/geoLocations/geoLocationPoint/pointLongitude.label"),
)

metadata_geoLocations_geoLocationPolygons_inPolygonPoint_pointLatitude = TermsFacet(
    field="metadata.geoLocations.geoLocationPolygons.inPolygonPoint.pointLatitude",
    label=_(
        "metadata/geoLocations/geoLocationPolygons/inPolygonPoint/pointLatitude.label"
    ),
)

metadata_geoLocations_geoLocationPolygons_inPolygonPoint_pointLongitude = TermsFacet(
    field="metadata.geoLocations.geoLocationPolygons.inPolygonPoint.pointLongitude",
    label=_(
        "metadata/geoLocations/geoLocationPolygons/inPolygonPoint/pointLongitude.label"
    ),
)

metadata_geoLocations_geoLocationPolygons_polygonPoints_pointLatitude = TermsFacet(
    field="metadata.geoLocations.geoLocationPolygons.polygonPoints.pointLatitude",
    label=_(
        "metadata/geoLocations/geoLocationPolygons/polygonPoints/pointLatitude.label"
    ),
)

metadata_geoLocations_geoLocationPolygons_polygonPoints_pointLongitude = TermsFacet(
    field="metadata.geoLocations.geoLocationPolygons.polygonPoints.pointLongitude",
    label=_(
        "metadata/geoLocations/geoLocationPolygons/polygonPoints/pointLongitude.label"
    ),
)

metadata_language = TermsFacet(
    field="metadata.language", label=_("metadata/language.label")
)

metadata_publicationYear = TermsFacet(
    field="metadata.publicationYear", label=_("metadata/publicationYear.label")
)

metadata_publisher_lang = TermsFacet(
    field="metadata.publisher.lang", label=_("metadata/publisher/lang.label")
)

metadata_publisher_name = TermsFacet(
    field="metadata.publisher.name", label=_("metadata/publisher/name.label")
)

metadata_publisher_publisherIdentifier = TermsFacet(
    field="metadata.publisher.publisherIdentifier",
    label=_("metadata/publisher/publisherIdentifier.label"),
)

metadata_publisher_publisherIdentifierScheme = TermsFacet(
    field="metadata.publisher.publisherIdentifierScheme",
    label=_("metadata/publisher/publisherIdentifierScheme.label"),
)

metadata_publisher_schemeURI = TermsFacet(
    field="metadata.publisher.schemeURI", label=_("metadata/publisher/schemeURI.label")
)

metadata_relatedIdentifiers_relatedIdentifier = TermsFacet(
    field="metadata.relatedIdentifiers.relatedIdentifier",
    label=_("metadata/relatedIdentifiers/relatedIdentifier.label"),
)

metadata_relatedIdentifiers_relatedIdentifierType = TermsFacet(
    field="metadata.relatedIdentifiers.relatedIdentifierType",
    label=_("metadata/relatedIdentifiers/relatedIdentifierType.label"),
)

metadata_relatedIdentifiers_relatedMetadataScheme = TermsFacet(
    field="metadata.relatedIdentifiers.relatedMetadataScheme",
    label=_("metadata/relatedIdentifiers/relatedMetadataScheme.label"),
)

metadata_relatedIdentifiers_relationType = TermsFacet(
    field="metadata.relatedIdentifiers.relationType",
    label=_("metadata/relatedIdentifiers/relationType.label"),
)

metadata_relatedIdentifiers_resourceTypeGeneral = TermsFacet(
    field="metadata.relatedIdentifiers.resourceTypeGeneral",
    label=_("metadata/relatedIdentifiers/resourceTypeGeneral.label"),
)

metadata_relatedIdentifiers_schemeType = TermsFacet(
    field="metadata.relatedIdentifiers.schemeType",
    label=_("metadata/relatedIdentifiers/schemeType.label"),
)

metadata_relatedIdentifiers_schemeURI = TermsFacet(
    field="metadata.relatedIdentifiers.schemeURI",
    label=_("metadata/relatedIdentifiers/schemeURI.label"),
)

metadata_relatedItems_contributors_affiliation_affiliationIdentifier = TermsFacet(
    field="metadata.relatedItems.contributors.affiliation.affiliationIdentifier",
    label=_(
        "metadata/relatedItems/contributors/affiliation/affiliationIdentifier.label"
    ),
)

metadata_relatedItems_contributors_affiliation_affiliationIdentifierScheme = TermsFacet(
    field="metadata.relatedItems.contributors.affiliation.affiliationIdentifierScheme",
    label=_(
        "metadata/relatedItems/contributors/affiliation/affiliationIdentifierScheme.label"
    ),
)

metadata_relatedItems_contributors_affiliation_name = TermsFacet(
    field="metadata.relatedItems.contributors.affiliation.name",
    label=_("metadata/relatedItems/contributors/affiliation/name.label"),
)

metadata_relatedItems_contributors_affiliation_schemeURI = TermsFacet(
    field="metadata.relatedItems.contributors.affiliation.schemeURI",
    label=_("metadata/relatedItems/contributors/affiliation/schemeURI.label"),
)

metadata_relatedItems_contributors_contributorType = TermsFacet(
    field="metadata.relatedItems.contributors.contributorType",
    label=_("metadata/relatedItems/contributors/contributorType.label"),
)

metadata_relatedItems_contributors_familyName = TermsFacet(
    field="metadata.relatedItems.contributors.familyName",
    label=_("metadata/relatedItems/contributors/familyName.label"),
)

metadata_relatedItems_contributors_givenName = TermsFacet(
    field="metadata.relatedItems.contributors.givenName",
    label=_("metadata/relatedItems/contributors/givenName.label"),
)

metadata_relatedItems_contributors_lang = TermsFacet(
    field="metadata.relatedItems.contributors.lang",
    label=_("metadata/relatedItems/contributors/lang.label"),
)

metadata_relatedItems_contributors_name = TermsFacet(
    field="metadata.relatedItems.contributors.name",
    label=_("metadata/relatedItems/contributors/name.label"),
)

metadata_relatedItems_contributors_nameIdentifiers_nameIdentifier = TermsFacet(
    field="metadata.relatedItems.contributors.nameIdentifiers.nameIdentifier",
    label=_("metadata/relatedItems/contributors/nameIdentifiers/nameIdentifier.label"),
)

metadata_relatedItems_contributors_nameIdentifiers_nameIdentifierScheme = TermsFacet(
    field="metadata.relatedItems.contributors.nameIdentifiers.nameIdentifierScheme",
    label=_(
        "metadata/relatedItems/contributors/nameIdentifiers/nameIdentifierScheme.label"
    ),
)

metadata_relatedItems_contributors_nameIdentifiers_schemeURI = TermsFacet(
    field="metadata.relatedItems.contributors.nameIdentifiers.schemeURI",
    label=_("metadata/relatedItems/contributors/nameIdentifiers/schemeURI.label"),
)

metadata_relatedItems_contributors_nameType = TermsFacet(
    field="metadata.relatedItems.contributors.nameType",
    label=_("metadata/relatedItems/contributors/nameType.label"),
)

metadata_relatedItems_creators_affiliation_affiliationIdentifier = TermsFacet(
    field="metadata.relatedItems.creators.affiliation.affiliationIdentifier",
    label=_("metadata/relatedItems/creators/affiliation/affiliationIdentifier.label"),
)

metadata_relatedItems_creators_affiliation_affiliationIdentifierScheme = TermsFacet(
    field="metadata.relatedItems.creators.affiliation.affiliationIdentifierScheme",
    label=_(
        "metadata/relatedItems/creators/affiliation/affiliationIdentifierScheme.label"
    ),
)

metadata_relatedItems_creators_affiliation_name = TermsFacet(
    field="metadata.relatedItems.creators.affiliation.name",
    label=_("metadata/relatedItems/creators/affiliation/name.label"),
)

metadata_relatedItems_creators_affiliation_schemeURI = TermsFacet(
    field="metadata.relatedItems.creators.affiliation.schemeURI",
    label=_("metadata/relatedItems/creators/affiliation/schemeURI.label"),
)

metadata_relatedItems_creators_familyName = TermsFacet(
    field="metadata.relatedItems.creators.familyName",
    label=_("metadata/relatedItems/creators/familyName.label"),
)

metadata_relatedItems_creators_givenName = TermsFacet(
    field="metadata.relatedItems.creators.givenName",
    label=_("metadata/relatedItems/creators/givenName.label"),
)

metadata_relatedItems_creators_lang = TermsFacet(
    field="metadata.relatedItems.creators.lang",
    label=_("metadata/relatedItems/creators/lang.label"),
)

metadata_relatedItems_creators_name = TermsFacet(
    field="metadata.relatedItems.creators.name",
    label=_("metadata/relatedItems/creators/name.label"),
)

metadata_relatedItems_creators_nameIdentifiers_nameIdentifier = TermsFacet(
    field="metadata.relatedItems.creators.nameIdentifiers.nameIdentifier",
    label=_("metadata/relatedItems/creators/nameIdentifiers/nameIdentifier.label"),
)

metadata_relatedItems_creators_nameIdentifiers_nameIdentifierScheme = TermsFacet(
    field="metadata.relatedItems.creators.nameIdentifiers.nameIdentifierScheme",
    label=_(
        "metadata/relatedItems/creators/nameIdentifiers/nameIdentifierScheme.label"
    ),
)

metadata_relatedItems_creators_nameIdentifiers_schemeURI = TermsFacet(
    field="metadata.relatedItems.creators.nameIdentifiers.schemeURI",
    label=_("metadata/relatedItems/creators/nameIdentifiers/schemeURI.label"),
)

metadata_relatedItems_creators_nameType = TermsFacet(
    field="metadata.relatedItems.creators.nameType",
    label=_("metadata/relatedItems/creators/nameType.label"),
)

metadata_relatedItems_edition = TermsFacet(
    field="metadata.relatedItems.edition",
    label=_("metadata/relatedItems/edition.label"),
)

metadata_relatedItems_firstPage = TermsFacet(
    field="metadata.relatedItems.firstPage",
    label=_("metadata/relatedItems/firstPage.label"),
)

metadata_relatedItems_issue = TermsFacet(
    field="metadata.relatedItems.issue", label=_("metadata/relatedItems/issue.label")
)

metadata_relatedItems_lastPage = TermsFacet(
    field="metadata.relatedItems.lastPage",
    label=_("metadata/relatedItems/lastPage.label"),
)

metadata_relatedItems_number = TermsFacet(
    field="metadata.relatedItems.number", label=_("metadata/relatedItems/number.label")
)

metadata_relatedItems_numberType = TermsFacet(
    field="metadata.relatedItems.numberType",
    label=_("metadata/relatedItems/numberType.label"),
)

metadata_relatedItems_publicationYear = TermsFacet(
    field="metadata.relatedItems.publicationYear",
    label=_("metadata/relatedItems/publicationYear.label"),
)

metadata_relatedItems_publisher = TermsFacet(
    field="metadata.relatedItems.publisher",
    label=_("metadata/relatedItems/publisher.label"),
)

metadata_relatedItems_relatedItemIdentifier_relatedItemIdentifier = TermsFacet(
    field="metadata.relatedItems.relatedItemIdentifier.relatedItemIdentifier",
    label=_("metadata/relatedItems/relatedItemIdentifier/relatedItemIdentifier.label"),
)

metadata_relatedItems_relatedItemIdentifier_relatedItemIdentifierType = TermsFacet(
    field="metadata.relatedItems.relatedItemIdentifier.relatedItemIdentifierType",
    label=_(
        "metadata/relatedItems/relatedItemIdentifier/relatedItemIdentifierType.label"
    ),
)

metadata_relatedItems_relatedItemType = TermsFacet(
    field="metadata.relatedItems.relatedItemType",
    label=_("metadata/relatedItems/relatedItemType.label"),
)

metadata_relatedItems_relatedMetadataScheme = TermsFacet(
    field="metadata.relatedItems.relatedMetadataScheme",
    label=_("metadata/relatedItems/relatedMetadataScheme.label"),
)

metadata_relatedItems_relationType = TermsFacet(
    field="metadata.relatedItems.relationType",
    label=_("metadata/relatedItems/relationType.label"),
)

metadata_relatedItems_resourceTypeGeneral = TermsFacet(
    field="metadata.relatedItems.resourceTypeGeneral",
    label=_("metadata/relatedItems/resourceTypeGeneral.label"),
)

metadata_relatedItems_schemeType = TermsFacet(
    field="metadata.relatedItems.schemeType",
    label=_("metadata/relatedItems/schemeType.label"),
)

metadata_relatedItems_schemeURI = TermsFacet(
    field="metadata.relatedItems.schemeURI",
    label=_("metadata/relatedItems/schemeURI.label"),
)

metadata_relatedItems_titles_lang = TermsFacet(
    field="metadata.relatedItems.titles.lang",
    label=_("metadata/relatedItems/titles/lang.label"),
)

metadata_relatedItems_titles_titleType = TermsFacet(
    field="metadata.relatedItems.titles.titleType",
    label=_("metadata/relatedItems/titles/titleType.label"),
)

metadata_relatedItems_volume = TermsFacet(
    field="metadata.relatedItems.volume", label=_("metadata/relatedItems/volume.label")
)

metadata_resourceType_resourceType = TermsFacet(
    field="metadata.resourceType.resourceType",
    label=_("metadata/resourceType/resourceType.label"),
)

metadata_resourceType_resourceTypeGeneral = TermsFacet(
    field="metadata.resourceType.resourceTypeGeneral",
    label=_("metadata/resourceType/resourceTypeGeneral.label"),
)

metadata_rightsList_lang = TermsFacet(
    field="metadata.rightsList.lang", label=_("metadata/rightsList/lang.label")
)

metadata_rightsList_rights = TermsFacet(
    field="metadata.rightsList.rights", label=_("metadata/rightsList/rights.label")
)

metadata_rightsList_rightsIdentifier = TermsFacet(
    field="metadata.rightsList.rightsIdentifier",
    label=_("metadata/rightsList/rightsIdentifier.label"),
)

metadata_rightsList_rightsIdentifierScheme = TermsFacet(
    field="metadata.rightsList.rightsIdentifierScheme",
    label=_("metadata/rightsList/rightsIdentifierScheme.label"),
)

metadata_rightsList_rightsURI = TermsFacet(
    field="metadata.rightsList.rightsURI",
    label=_("metadata/rightsList/rightsURI.label"),
)

metadata_rightsList_schemeURI = TermsFacet(
    field="metadata.rightsList.schemeURI",
    label=_("metadata/rightsList/schemeURI.label"),
)

metadata_schemaVersion = TermsFacet(
    field="metadata.schemaVersion", label=_("metadata/schemaVersion.label")
)

metadata_sizes = TermsFacet(field="metadata.sizes", label=_("metadata/sizes.label"))

metadata_subjects_classificationCode = TermsFacet(
    field="metadata.subjects.classificationCode",
    label=_("metadata/subjects/classificationCode.label"),
)

metadata_subjects_lang = TermsFacet(
    field="metadata.subjects.lang", label=_("metadata/subjects/lang.label")
)

metadata_subjects_schemeURI = TermsFacet(
    field="metadata.subjects.schemeURI", label=_("metadata/subjects/schemeURI.label")
)

metadata_subjects_subject = TermsFacet(
    field="metadata.subjects.subject", label=_("metadata/subjects/subject.label")
)

metadata_subjects_subjectScheme = TermsFacet(
    field="metadata.subjects.subjectScheme",
    label=_("metadata/subjects/subjectScheme.label"),
)

metadata_subjects_valueURI = TermsFacet(
    field="metadata.subjects.valueURI", label=_("metadata/subjects/valueURI.label")
)

metadata_titles_lang = TermsFacet(
    field="metadata.titles.lang", label=_("metadata/titles/lang.label")
)

metadata_titles_titleType = TermsFacet(
    field="metadata.titles.titleType", label=_("metadata/titles/titleType.label")
)

metadata_url = TermsFacet(field="metadata.url", label=_("metadata/url.label"))

metadata_version = TermsFacet(
    field="metadata.version", label=_("metadata/version.label")
)

state = TermsFacet(field="state", label=_("state.label"))

state_timestamp = DateTimeFacet(
    field="state_timestamp", label=_("state_timestamp.label")
)


record_status = TermsFacet(field="record_status", label=_("record_status"))

has_draft = TermsFacet(field="has_draft", label=_("has_draft"))
